@@ -2,7 +2,7 @@ package Date::Holidays::TW;
 use strict;
 use utf8;
 
-our $VERSION = v0.3.0;
+our $VERSION = v0.4.0;
 
 use Exporter 'import';
 our @EXPORT_OK = qw(is_tw_holiday tw_holidays);
@@ -1254,6 +1254,125 @@ my %CAL = (
         "1225" => "星期六、星期日",
         "1231" => "星期六、星期日",
     },
+
+    2023 => {
+        "0101" => "開國紀念日",
+        "0102" => "補假",
+        "0108" => "星期六、星期日",
+        "0114" => "星期六、星期日",
+        "0115" => "星期六、星期日",
+        "0120" => "小年夜",
+        "0121" => "農曆除夕",
+        "0122" => "春節",
+        "0123" => "春節",
+        "0124" => "春節",
+        "0125" => "補假",
+        "0126" => "補假",
+        "0127" => "調整放假",
+        "0128" => "星期六、星期日",
+        "0129" => "星期六、星期日",
+        "0205" => "星期六、星期日",
+        "0211" => "星期六、星期日",
+        "0212" => "星期六、星期日",
+        "0219" => "星期六、星期日",
+        "0225" => "星期六、星期日",
+        "0226" => "星期六、星期日",
+        "0227" => "調整放假",
+        "0228" => "和平紀念日",
+        "0304" => "星期六、星期日",
+        "0305" => "星期六、星期日",
+        "0311" => "星期六、星期日",
+        "0312" => "星期六、星期日",
+        "0318" => "星期六、星期日",
+        "0319" => "星期六、星期日",
+        "0326" => "星期六、星期日",
+        "0401" => "星期六、星期日",
+        "0402" => "星期六、星期日",
+        "0403" => "調整放假",
+        "0404" => "兒童節",
+        "0405" => "民族掃墓節",
+        "0408" => "星期六、星期日",
+        "0409" => "星期六、星期日",
+        "0415" => "星期六、星期日",
+        "0416" => "星期六、星期日",
+        "0422" => "星期六、星期日",
+        "0423" => "星期六、星期日",
+        "0429" => "星期六、星期日",
+        "0430" => "星期六、星期日",
+        "0506" => "星期六、星期日",
+        "0507" => "星期六、星期日",
+        "0513" => "星期六、星期日",
+        "0514" => "星期六、星期日",
+        "0520" => "星期六、星期日",
+        "0521" => "星期六、星期日",
+        "0527" => "星期六、星期日",
+        "0528" => "星期六、星期日",
+        "0603" => "星期六、星期日",
+        "0604" => "星期六、星期日",
+        "0610" => "星期六、星期日",
+        "0611" => "星期六、星期日",
+        "0618" => "星期六、星期日",
+        "0622" => "端午節",
+        "0623" => "調整放假",
+        "0624" => "星期六、星期日",
+        "0625" => "星期六、星期日",
+        "0701" => "星期六、星期日",
+        "0702" => "星期六、星期日",
+        "0708" => "星期六、星期日",
+        "0709" => "星期六、星期日",
+        "0715" => "星期六、星期日",
+        "0716" => "星期六、星期日",
+        "0722" => "星期六、星期日",
+        "0723" => "星期六、星期日",
+        "0729" => "星期六、星期日",
+        "0730" => "星期六、星期日",
+        "0805" => "星期六、星期日",
+        "0806" => "星期六、星期日",
+        "0812" => "星期六、星期日",
+        "0813" => "星期六、星期日",
+        "0819" => "星期六、星期日",
+        "0820" => "星期六、星期日",
+        "0826" => "星期六、星期日",
+        "0827" => "星期六、星期日",
+        "0902" => "星期六、星期日",
+        "0903" => "星期六、星期日",
+        "0909" => "星期六、星期日",
+        "0910" => "星期六、星期日",
+        "0916" => "星期六、星期日",
+        "0917" => "星期六、星期日",
+        "0924" => "星期六、星期日",
+        "0929" => "中秋節",
+        "0930" => "星期六、星期日",
+        "1001" => "星期六、星期日",
+        "1007" => "星期六、星期日",
+        "1008" => "星期六、星期日",
+        "1009" => "調整放假",
+        "1010" => "國慶日",
+        "1014" => "星期六、星期日",
+        "1015" => "星期六、星期日",
+        "1021" => "星期六、星期日",
+        "1022" => "星期六、星期日",
+        "1028" => "星期六、星期日",
+        "1029" => "星期六、星期日",
+        "1104" => "星期六、星期日",
+        "1105" => "星期六、星期日",
+        "1111" => "星期六、星期日",
+        "1112" => "星期六、星期日",
+        "1118" => "星期六、星期日",
+        "1119" => "星期六、星期日",
+        "1125" => "星期六、星期日",
+        "1126" => "星期六、星期日",
+        "1202" => "星期六、星期日",
+        "1203" => "星期六、星期日",
+        "1209" => "星期六、星期日",
+        "1210" => "星期六、星期日",
+        "1216" => "星期六、星期日",
+        "1217" => "星期六、星期日",
+        "1223" => "星期六、星期日",
+        "1224" => "星期六、星期日",
+        "1230" => "星期六、星期日",
+        "1231" => "星期六、星期日",
+    },
 );
 
 sub new { bless {}, shift };
